]> git.mxchange.org Git - mailer.git/blobdiff - ref.php
Fix for removed userid
[mailer.git] / ref.php
diff --git a/ref.php b/ref.php
index d733f53f890d8728273b27f436b060d88761f03d..905abf7122db965a1c657283365f881151d8f2b3 100644 (file)
--- a/ref.php
+++ b/ref.php
@@ -45,7 +45,7 @@ $GLOBALS['module'] = "ref"; $CSS = -1;
 require ("inc/config.php");
 
 // Redirect only to registration page when this script is installed
-if (defined('mxchange_installed') && (isBooleanConstantAndTrue('mxchange_installed'))) {
+if (isBooleanConstantAndTrue('mxchange_installed')) {
        // Base URL for redirection
        switch ($_CONFIG['refid_target'])
        {
@@ -73,14 +73,20 @@ if (defined('mxchange_installed') && (isBooleanConstantAndTrue('mxchange_install
                } // END - if
 
                // Also edit this 0 !
-               if (empty($ref)) $ref = "0";
+               if (empty($ref)) $ref = 0;
+
+               // Update session
+               set_session('refid', $ref);
 
                // We have an refid here. So we simply add it
                $URL .= bigintval($ref);
 
-               // Update ref counter
-               $result = SQL_QUERY_ESC("UPDATE "._MYSQL_PREFIX."_user_data SET ref_clicks=ref_clicks+1 WHERE userid=%s LIMIT 1",
-                       array(bigintval($ref)), __FILE__, __LINE__);
+               // Is the refid valid?
+               if ($ref > 0) {
+                       // Update ref counter
+                       $result = SQL_QUERY_ESC("UPDATE "._MYSQL_PREFIX."_user_data SET ref_clicks=ref_clicks+1 WHERE userid=%s LIMIT 1",
+                               array(bigintval($ref)), __FILE__, __LINE__);
+               } // END - if
        } else {
                // No refid and we add our refid (don't forget to set $def_refid!)
                $URL = URL."/index.php";